Plotting
========

We embed some plotting capabilities in the library to help you visualize your data.

.. toctree::

   plot-featurecollection
   plot-image
   plot-imagecollection
   map-image
   map-featurecollection